==> haskell-monad-logger-0.3.24-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.24
id: monad-logger-0.3.24-FiZCIIbO7ui1TJ2Lwn7uL8
key: monad-logger-0.3.24-FiZCIIbO7ui1TJ2Lwn7uL8
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A class of monads which can log messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/monad-logger>.
category: System
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
abi: fe4aace7b3c45c4967fb5412a99dcf3e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-logger-0.3.24
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-logger-0.3.24
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-logger-0.3.24
hs-libraries: HSmonad-logger-0.3.24-FiZCIIbO7ui1TJ2Lwn7uL8
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-ASXD1Y7ORRDJz1X54jUL8d
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    stm-chans-3.0.0.4-5ztCObT9euH4tDnVX3B1eF template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.24-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.24
id: monad-logger-0.3.24-3TRZywB0PN0FNMMmN151zF
key: monad-logger-0.3.24-3TRZywB0PN0FNMMmN151zF
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A class of monads which can log messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/monad-logger>.
category: System
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
abi: 4a62b56a14e97b11f7f57ce46ba79bfb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-logger-0.3.24
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-logger-0.3.24
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-logger-0.3.24
hs-libraries: HSmonad-logger-0.3.24-3TRZywB0PN0FNMMmN151zF
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-LbHEhSYrKrIKl2iEItQ5UA
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-1KSNxjE2NJ14puKDEfe1S4
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-loops-0.4.3-2fzM5iYl9mFG5pm27bHqMF
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    stm-chans-3.0.0.4-5ztCObT9euH4tDnVX3B1eF template-haskell-2.11.0.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
